@@ -4,7 +4,6 @@ use async_std::net;
 #[cfg(unix)]
 use async_std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
 use async_std::task::{Context, Poll};
-use cap_primitives::{ambient_authority, AmbientAuthority};
 #[cfg(not(windows))]
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
 #[cfg(windows)]
@@ -36,12 +35,10 @@ impl TcpStream {
     /// Constructs a new instance of `Self` from the given
     /// `async_std::net::TcpStream`.
     ///
-    /// # Ambient Authority
-    ///
-    /// `async_std::net::TcpStream` is not sandboxed and may access any address
-    /// that the host process has access to.
+    /// This grants access the resources the `async_std::net::TcpStream`
+    /// instance already has access to.
     #[inline]
-    pub fn from_std(std: net::TcpStream, _: AmbientAuthority) -> Self {
+    pub fn from_std(std: net::TcpStream) -> Self {
         Self { std }
     }
 
@@ -129,7 +126,7 @@ impl TcpStream {
 impl FromRawFd for TcpStream {
     #[inline]
     unsafe fn from_raw_fd(fd: RawFd) -> Self {
-        Self::from_std(net::TcpStream::from_raw_fd(fd), ambient_authority())
+        Self::from_std(net::TcpStream::from_raw_fd(fd))
     }
 }
 
@@ -137,7 +134,7 @@ impl FromRawFd for TcpStream {
 impl FromFd for TcpStream {
     #[inline]
     fn from_fd(fd: OwnedFd) -> Self {
-        Self::from_std(net::TcpStream::from_fd(fd), ambient_authority())
+        Self::from_std(net::TcpStream::from_fd(fd))
     }
 }
 
@@ -145,7 +142,7 @@ impl FromFd for TcpStream {
 impl FromRawSocket for TcpStream {
     #[inline]
     unsafe fn from_raw_socket(socket: RawSocket) -> Self {
-        Self::from_std(net::TcpStream::from_raw_socket(socket), ambient_authority())
+        Self::from_std(net::TcpStream::from_raw_socket(socket))
     }
 }
 
@@ -153,7 +150,7 @@ impl FromRawSocket for TcpStream {
 impl FromSocket for TcpStream {
     #[inline]
     fn from_socket(socket: OwnedSocket) -> Self {
-        Self::from_std(net::TcpStream::from_socket(socket), ambient_authority())
+        Self::from_std(net::TcpStream::from_socket(socket))
     }
 }
 
